# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/foxtrot',
                'doc_host': 'https://licenseplated.github.io',
                'git_url': 'https://github.com/licenseplated/foxtrot',
                'lib_path': 'foxtrot'},
  'syms': { 'foxtrot.core': { 'foxtrot.core.Workflow': ('core.html#workflow', 'foxtrot/core.py'),
                              'foxtrot.core.Workflow.__init__': ('core.html#workflow.__init__', 'foxtrot/core.py'),
                              'foxtrot.core.Workflow.cache': ('core.html#workflow.cache', 'foxtrot/core.py')}}}
